==> checker-3.49.3.jar: annotated-jdk/src/java.security.jgss/share/classes/sun/security/jgss/TokenTracker.java <==
/*
 * Copyright (c) 2000, 2006, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package sun.security.jgss;

import org.checkerframework.dataflow.qual.Pure;
import org.ietf.jgss.MessageProp;
import java.util.LinkedList;

public class TokenTracker {

    public TokenTracker(int initNumber) {
    }

    synchronized public final void getProps(int number, MessageProp prop);

    public String toString();

    class Entry {

        final int compareTo(int number);

        @Pure
        final boolean contains(int number);

        final void append(int number);

        final void setInterval(int start, int end);

        final void setEnd(int end);

        final void setStart(int start);

        final int getStart();

        final int getEnd();

        public String toString();
    }
}

==> checker-3.53.1.jar: annotated-jdk/src/java.security.jgss/share/classes/sun/security/jgss/TokenTracker.java <==
/*
 * Copyright (c) 2000, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package sun.security.jgss;

import org.checkerframework.dataflow.qual.Pure;
import org.ietf.jgss.MessageProp;
import java.util.LinkedList;

public class TokenTracker {

    public TokenTracker(int initNumber) {
    }

    public final synchronized void getProps(int number, MessageProp prop);

    public String toString();

    static class Entry {

        final int compareTo(int number);

        @Pure
        final boolean contains(int number);

        final void append(int number);

        final void setInterval(int start, int end);

        final void setEnd(int end);

        final void setStart(int start);

        final int getStart();

        final int getEnd();

        public String toString();
    }
}
